==> haskell-securemem-0.1.10-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 securemem
version:              0.1.10
visibility:           public
id:                   securemem-0.1.10-Bd4DajDBrG9HFY3HcdakkQ
key:                  securemem-0.1.10-Bd4DajDBrG9HFY3HcdakkQ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-securemem
synopsis:
    abstraction to an auto scrubbing and const time eq, memory chunk.

description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.

category:             Data
abi:                  b1ec8831b5bc08fd5c5046db7852b7cd
exposed:              True
exposed-modules:      Data.SecureMem
import-dirs:          /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/securemem-0.1.10
hs-libraries:         HSsecuremem-0.1.10-Bd4DajDBrG9HFY3HcdakkQ
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 ghc-prim-0.7.0
    memory-0.16.0-C1aSJjn86k58WRNtXw4yyI

haddock-interfaces:   /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html:         /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.10-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 securemem
version:              0.1.10
visibility:           public
id:                   securemem-0.1.10-6QzN0fGwj6UJJ4P3JoJYKy
key:                  securemem-0.1.10-6QzN0fGwj6UJJ4P3JoJYKy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-securemem
synopsis:
    abstraction to an auto scrubbing and const time eq, memory chunk.

description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.

category:             Data
abi:                  a87bc0198838a1f03f0c033d6088876f
exposed:              True
exposed-modules:      Data.SecureMem
import-dirs:          /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/securemem-0.1.10
hs-libraries:         HSsecuremem-0.1.10-6QzN0fGwj6UJJ4P3JoJYKy
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 ghc-prim-0.7.0
    memory-0.16.0-KCvRQBtf1MgDfoYCEPHsWl

haddock-interfaces:   /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html:         /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
